[−][src]Enum unicode_types::katakana::Katakana
An enum to represent all characters in the Katakana block.
Variants
DashHiraganaDoubleHyphen\u{30a0}: '゠'
LetterSmallA\u{30a1}: 'ァ'
LetterA\u{30a2}: 'ア'
LetterSmallI\u{30a3}: 'ィ'
LetterI\u{30a4}: 'イ'
LetterSmallU\u{30a5}: 'ゥ'
LetterU\u{30a6}: 'ウ'
LetterSmallE\u{30a7}: 'ェ'
LetterE\u{30a8}: 'エ'
LetterSmallO\u{30a9}: 'ォ'
LetterO\u{30aa}: 'オ'
LetterKa\u{30ab}: 'カ'
LetterGa\u{30ac}: 'ガ'
LetterKi\u{30ad}: 'キ'
LetterGi\u{30ae}: 'ギ'
LetterKu\u{30af}: 'ク'
LetterGu\u{30b0}: 'グ'
LetterKe\u{30b1}: 'ケ'
LetterGe\u{30b2}: 'ゲ'
LetterKo\u{30b3}: 'コ'
LetterGo\u{30b4}: 'ゴ'
LetterSa\u{30b5}: 'サ'
LetterZa\u{30b6}: 'ザ'
LetterSi\u{30b7}: 'シ'
LetterZi\u{30b8}: 'ジ'
LetterSu\u{30b9}: 'ス'
LetterZu\u{30ba}: 'ズ'
LetterSe\u{30bb}: 'セ'
LetterZe\u{30bc}: 'ゼ'
LetterSo\u{30bd}: 'ソ'
LetterZo\u{30be}: 'ゾ'
LetterTa\u{30bf}: 'タ'
LetterDa\u{30c0}: 'ダ'
LetterTi\u{30c1}: 'チ'
LetterDi\u{30c2}: 'ヂ'
LetterSmallTu\u{30c3}: 'ッ'
LetterTu\u{30c4}: 'ツ'
LetterDu\u{30c5}: 'ヅ'
LetterTe\u{30c6}: 'テ'
LetterDe\u{30c7}: 'デ'
LetterTo\u{30c8}: 'ト'
LetterDo\u{30c9}: 'ド'
LetterNa\u{30ca}: 'ナ'
LetterNi\u{30cb}: 'ニ'
LetterNu\u{30cc}: 'ヌ'
LetterNe\u{30cd}: 'ネ'
LetterNo\u{30ce}: 'ノ'
LetterHa\u{30cf}: 'ハ'
LetterBa\u{30d0}: 'バ'
LetterPa\u{30d1}: 'パ'
LetterHi\u{30d2}: 'ヒ'
LetterBi\u{30d3}: 'ビ'
LetterPi\u{30d4}: 'ピ'
LetterHu\u{30d5}: 'フ'
LetterBu\u{30d6}: 'ブ'
LetterPu\u{30d7}: 'プ'
LetterHe\u{30d8}: 'ヘ'
LetterBe\u{30d9}: 'ベ'
LetterPe\u{30da}: 'ペ'
LetterHo\u{30db}: 'ホ'
LetterBo\u{30dc}: 'ボ'
LetterPo\u{30dd}: 'ポ'
LetterMa\u{30de}: 'マ'
LetterMi\u{30df}: 'ミ'
LetterMu\u{30e0}: 'ム'
LetterMe\u{30e1}: 'メ'
LetterMo\u{30e2}: 'モ'
LetterSmallYa\u{30e3}: 'ャ'
LetterYa\u{30e4}: 'ヤ'
LetterSmallYu\u{30e5}: 'ュ'
LetterYu\u{30e6}: 'ユ'
LetterSmallYo\u{30e7}: 'ョ'
LetterYo\u{30e8}: 'ヨ'
LetterRa\u{30e9}: 'ラ'
LetterRi\u{30ea}: 'リ'
LetterRu\u{30eb}: 'ル'
LetterRe\u{30ec}: 'レ'
LetterRo\u{30ed}: 'ロ'
LetterSmallWa\u{30ee}: 'ヮ'
LetterWa\u{30ef}: 'ワ'
LetterWi\u{30f0}: 'ヰ'
LetterWe\u{30f1}: 'ヱ'
LetterWo\u{30f2}: 'ヲ'
LetterN\u{30f3}: 'ン'
LetterVu\u{30f4}: 'ヴ'
LetterSmallKa\u{30f5}: 'ヵ'
LetterSmallKe\u{30f6}: 'ヶ'
LetterVa\u{30f7}: 'ヷ'
LetterVi\u{30f8}: 'ヸ'
LetterVe\u{30f9}: 'ヹ'
LetterVo\u{30fa}: 'ヺ'
MiddleDot\u{30fb}: '・'
DashHiraganaProlongedSoundMark\u{30fc}: 'ー'
IterationMark\u{30fd}: 'ヽ'
VoicedIterationMark\u{30fe}: 'ヾ'
Methods
impl Katakana[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case